==> piwigo-2.5.1.zip: piwigo/plugins/LocalFilesEditor/language/tr_TR/plugin.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based photo gallery                                    |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2013 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+

$lang['locfiledit_onglet_localconf'] = 'Yerel ayarlar';
$lang['locfiledit_onglet_css'] = 'CSS';
$lang['locfiledit_onglet_tpl'] = 'Şablonlar';
$lang['locfiledit_onglet_lang'] = 'Diller';
$lang['locfiledit_onglet_plug'] = 'Kişisel Eklenti';
$lang['locfiledit_cant_save'] = 'Seçili dosyanın yazılabilirlik izni yok. Lütfen "local/" klasörünü yazılabilir (chmod) olup olmadığını kontrol ediniz.';
$lang['locfiledit_newfile'] = 'Aşağıya bazı bilgiler girilmeden dosya yaratılmaz.
Bilgiler girilip kaydedildikten sonra dosya yaratılacaktır.';
$lang['locfiledit_save_config'] = 'Dosya başarıyla yazıldı.';
$lang['locfiledit_show_default'] = 'Referans dosyasını göster: ';
$lang['locfiledit_save_bak'] = 'Yedekleme kopyası kaydedilirken yaratılacak.';
$lang['locfiledit_saved_bak'] = 'Yedekleme dosyası yaratıldı (%s)';
$lang['locfiledit_save_file'] = 'Dosyayı kaydet';
$lang['locfiledit_choose_file'] = 'Düzenlenecek dosyayı seçiniz';
$lang['locfiledit_edit'] = 'Düzenle';
$lang['locfiledit_restore'] = 'Yedekleme dosyasını geri yükle';
$lang['locfiledit_restore_confirm'] = 'Lütfen onaylayınız? 
Bir sonraki kaydetmeye kadar geri yükleme etkin olmayacak.';
$lang['locfiledit_bak_loaded1'] = 'Yedekleme dosyası yüklendi.';
$lang['locfiledit_bak_loaded2'] = 'Geri yüklemek için dosyayı kaydetmeniz gerekir.';
$lang['locfiledit_syntax_error'] = 'Sözdizimi (syntax) hatası! Dosya kaydedilemiyor.';
$lang['locfiledit_new_tpl'] = 'Yeni dosya yarat';
$lang['locfiledit_new_filename'] = 'Dosya adı';
$lang['locfiledit_model'] = 'Model';
$lang['locfiledit_empty_page'] = 'Boş sayfa';
$lang['locfiledit_parent_directory'] = 'Üst dizin';
$lang['locfiledit_filename_error'] = 'Dosya adında yasaklanmış karakterler var.';
$lang['locfiledit_file_already_exists'] = 'Bu dosya zaten var.';
$lang['locfiledit_model_error'] = 'Bir model seçmek zorundasınız.';
$lang['locfiledit_empty_filename'] = 'Dosya ismini girmelisiniz.';
$lang['locfiledit_webmaster_only'] = 'Sadece yöneticiler dosyaları yaratabilir veya değiştirebilir.';
?>

==> piwigo-2.5.3.zip: piwigo/plugins/LocalFilesEditor/language/tr_TR/plugin.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based photo gallery                                    |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2013 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+

$lang['locfiledit_onglet_localconf'] = 'Yerel yapılandırma';
$lang['locfiledit_onglet_css'] = 'CSS';
$lang['locfiledit_onglet_tpl'] = 'Şablonlar';
$lang['locfiledit_onglet_lang'] = 'Diller';
$lang['locfiledit_onglet_plug'] = 'Kişisel Eklenti';
$lang['locfiledit_cant_save'] = 'Seçili dosyanın yazılabilirlik izni yok. Lütfen "local/" klasörünü yazılabilir (chmod) olup olmadığını kontrol ediniz.';
$lang['locfiledit_newfile'] = 'Aşağıya bazı bilgiler girilmeden dosya yaratılmaz.
Bilgiler girilip kaydedildikten sonra dosya yaratılacaktır.';
$lang['locfiledit_save_config'] = 'Dosya başarıyla yazıldı.';
$lang['locfiledit_show_default'] = 'Referans dosyasını göster: ';
$lang['locfiledit_save_bak'] = 'Yedekleme kopyası kaydedilirken yaratılacak.';
$lang['locfiledit_saved_bak'] = 'Yedekleme dosyası yaratıldı (%s)';
$lang['locfiledit_save_file'] = 'Dosyayı kaydet';
$lang['locfiledit_choose_file'] = 'Düzenlenecek dosyayı seçiniz';
$lang['locfiledit_edit'] = 'Düzenle';
$lang['locfiledit_restore'] = 'Yedekleme dosyasını geri yükle';
$lang['locfiledit_restore_confirm'] = 'Lütfen onaylayınız? 
Bir sonraki kaydetmeye kadar geri yükleme etkin olmayacak.';
$lang['locfiledit_bak_loaded1'] = 'Yedekleme dosyası yüklendi.';
$lang['locfiledit_bak_loaded2'] = 'Geri yüklemek için dosyayı kaydetmeniz gerekir.';
$lang['locfiledit_syntax_error'] = 'Sözdizimi (syntax) hatası! Dosya kaydedilemiyor.';
$lang['locfiledit_new_tpl'] = 'Yeni dosya yarat';
$lang['locfiledit_new_filename'] = 'Dosya adı';
$lang['locfiledit_model'] = 'Model';
$lang['locfiledit_empty_page'] = 'Boş sayfa';
$lang['locfiledit_parent_directory'] = 'Üst dizin';
$lang['locfiledit_filename_error'] = 'Dosya adında yasaklanmış karakterler var.';
$lang['locfiledit_file_already_exists'] = 'Bu dosya zaten var.';
$lang['locfiledit_model_error'] = 'Bir model seçmelisiniz.';
$lang['locfiledit_empty_filename'] = 'Dosya ismini girmelisiniz.';
$lang['locfiledit_webmaster_only'] = 'Sadece yöneticiler yerel dosyaları yaratabilir veya değiştirebilir.';
?>
